@@ -55,12 +55,12 @@ void play_sound(const gchar* file, editor_data_t* data)
   GstState state;
   GstState pending;
   int stret = gst_element_get_state(data->sound_player, &state, &pending, GST_CLOCK_TIME_NONE);
-  g_object_set(data->sound_player, "uri", g_filename_to_uri(file, NULL, NULL));
+  g_object_set(data->sound_player, "uri", g_filename_to_uri(file, NULL, NULL), NULL);
   int ret2 = gst_element_set_state(data->sound_player, GST_STATE_PLAYING);
  
 }
 
-gchar* get_profile_display_name(const gchar* profile_name)
+const gchar* get_profile_display_name(const gchar* profile_name)
 {
   if(g_strcmp0(profile_name, "silent")==0)
   {
@@ -72,11 +72,12 @@ gchar* get_profile_display_name(const gchar* profile_name)
   }
   else
   {
-    return g_strdup(profile_name);
+    return profile_name;
   }
 }
 
-void read_predefined_ringtones(editor_data_t* data)
+static void 
+read_predefined_ringtones(editor_data_t* data)
 {
   GIOChannel* channel;
   GRegex* regex;
@@ -142,7 +143,7 @@ void read_predefined_ringtones(editor_data_t* data)
   g_io_channel_unref(channel);
 }
 
-gchar*
+static gchar*
 get_display_value_from_file_name(const gchar* value, GtkListStore* list_store, GtkTreeIter* iter)
 {
   GFile* file;
@@ -155,7 +156,7 @@ get_display_value_from_file_name(const gchar* value, GtkListStore* list_store, G
   return basename;
 }
 
-gchar*
+static gchar*
 get_display_value(const gchar* value, GtkListStore* list_store, GtkTreeIter* iter)
 {
   gboolean valid = gtk_tree_model_get_iter_first (GTK_TREE_MODEL(list_store), iter);
@@ -227,9 +228,13 @@ void set_profile_status_icon_value(editor_data_t* data)
     GtkWidget* image;
     if(gtk_icon_theme_has_icon(gtk_icon_theme_get_default (), 
 			       icon_name))
-      image = gtk_image_new_from_icon_name(icon_name, 18);
+      {
+	image = gtk_image_new_from_icon_name(icon_name, 18);
+      }
     else
-      image = gtk_image_new_from_file(icon_name);
+      {
+	image = gtk_image_new_from_file(icon_name);
+      }
     
     gtk_button_set_image(GTK_BUTTON(data->iconButton), image);
   }
@@ -290,9 +295,10 @@ save_profile_tone_value(gchar** tone, GtkWidget* button, GtkListStore* list_stor
   GtkTreeIter iter;
   const gchar* value = hildon_button_get_value(HILDON_BUTTON(button));
   get_iter_for_value(list_store, value, &iter);
-  gtk_tree_model_get(GTK_TREE_MODEL(list_store), &iter,
-		     1, tone,
-		     -1);
+  if(gtk_list_store_iter_is_valid(list_store, &iter))
+    gtk_tree_model_get(GTK_TREE_MODEL(list_store), &iter,
+		       1, tone,
+		       -1);
 }
 
 void
@@ -328,7 +334,7 @@ save_profile_values(const gchar* profile_name, editor_data_t* data)
 void add_tone_to_list_store(GtkButton* button, GtkWidget* selector)
 {
   GtkWidget* dialog;
-  GtkWidget* parent = gtk_widget_get_parent(GTK_WIDGET(button));
+  GtkWidget* parent = gtk_widget_get_toplevel(GTK_WIDGET(button));
   GtkListStore* list_store = GTK_LIST_STORE(hildon_touch_selector_get_model(HILDON_TOUCH_SELECTOR(selector), 0));
 										    
   parent = gtk_widget_get_parent(parent);
@@ -340,6 +346,7 @@ void add_tone_to_list_store(GtkButton* button, GtkWidget* selector)
   //  gtk_file_filter_add_mime_type(fileFilter, "audio/midi");
   gtk_file_filter_add_mime_type(fileFilter, "audio/mp4");
   gtk_file_filter_add_mime_type(fileFilter, "audio/aac");
+  gtk_file_filter_add_mime_type(fileFilter, "audio/ogg");
   gtk_file_chooser_set_filter(GTK_FILE_CHOOSER(dialog), fileFilter);
 
 
@@ -351,7 +358,6 @@ void add_tone_to_list_store(GtkButton* button, GtkWidget* selector)
     gchar* filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
     GtkTreeIter iter;
     gchar* display_value = get_display_value(filename, list_store, &iter);
-
     hildon_touch_selector_select_iter(HILDON_TOUCH_SELECTOR(selector),
 				      0, &iter, TRUE);
     g_free(filename);
@@ -422,7 +428,8 @@ show_tone_selector(GtkListStore* list_store, GtkWidget* button, GtkWidget* selec
   gtk_widget_destroy(dialog);
 }
 
-GtkWidget* create_tone_selector_widget(GtkListStore* list_store)
+static GtkWidget* 
+create_tone_selector_widget(GtkListStore* list_store)
 {
   GtkWidget* widget = hildon_touch_selector_new();
   GtkCellRenderer* renderer;
@@ -440,39 +447,44 @@ GtkWidget* create_tone_selector_widget(GtkListStore* list_store)
   return widget; 
 }
 
+static
 void
 show_ringtone_selector(GtkWidget* button, editor_data_t *data)
 {
-  g_object_set(data->sound_player, "volume", gtk_range_get_value(GTK_RANGE(data->ringtoneVolumeSlider))/100.0);
+  g_object_set(data->sound_player, "volume", gtk_range_get_value(GTK_RANGE(data->ringtoneVolumeSlider))/100.0, NULL);
   data->ringtoneSelector=create_tone_selector_widget(data->ringingTone);
   show_tone_selector(data->ringingTone, data->ringtoneButton, data->ringtoneSelector, data);
 }
+
+static
 void
 show_smstone_selector(GtkWidget* button, editor_data_t *data)
 {
-  g_object_set(data->sound_player, "volume", gtk_range_get_value(GTK_RANGE(data->smsVolumeSlider))/100.0);
+  g_object_set(data->sound_player, "volume", gtk_range_get_value(GTK_RANGE(data->smsVolumeSlider))/100.0, NULL);
   data->smstoneSelector=create_tone_selector_widget(data->smsTone);
   show_tone_selector(data->smsTone, data->smstoneButton, data->smstoneSelector, data);
 }
 
+static
 void
 show_imtone_selector(GtkWidget* button, editor_data_t *data)
 {
-  g_object_set(data->sound_player, "volume", gtk_range_get_value(GTK_RANGE(data->imVolumeSlider))/100.0);
+  g_object_set(data->sound_player, "volume", gtk_range_get_value(GTK_RANGE(data->imVolumeSlider))/100.0, NULL);
   data->imtoneSelector=create_tone_selector_widget(data->imTone);
   show_tone_selector(data->imTone, data->imtoneButton, data->imtoneSelector, data);
 }
 
+static
 void
 show_emailtone_selector(GtkWidget* button, editor_data_t *data)
 {
-  g_object_set(data->sound_player, "volume", gtk_range_get_value(GTK_RANGE(data->emailVolumeSlider))/100.0);
+  g_object_set(data->sound_player, "volume", gtk_range_get_value(GTK_RANGE(data->emailVolumeSlider))/100.0, NULL);
   data->emailtoneSelector=create_tone_selector_widget(data->emailTone);
   show_tone_selector(data->emailTone, data->emailtoneButton, data->emailtoneSelector, data);
 }
 
-
-void init_editor_tone_selector_widgets(editor_data_t* app_data)
+static void 
+init_editor_tone_selector_widgets(editor_data_t* app_data)
 {
   app_data->imTone = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_STRING);
   app_data->emailTone = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_STRING);
@@ -521,7 +533,8 @@ void init_editor_tone_selector_widgets(editor_data_t* app_data)
   
 }
 
-void init_editor_tone_volume_widgets(editor_data_t* app_data)
+static void 
+init_editor_tone_volume_widgets(editor_data_t* app_data)
 {
   app_data->ringtoneVolumeSlider = hildon_gtk_hscale_new();
   gtk_scale_set_digits(GTK_SCALE(app_data->ringtoneVolumeSlider), 0);
@@ -545,7 +558,8 @@ void init_editor_tone_volume_widgets(editor_data_t* app_data)
 			   
 }
 
-GtkWidget* create_sound_level_widget(GtkListStore* list_store, gchar* title)
+static GtkWidget* 
+create_sound_level_widget(GtkListStore* list_store, gchar* title)
 {
   GtkWidget* selector;
   GtkCellRenderer* renderer;
@@ -570,7 +584,8 @@ GtkWidget* create_sound_level_widget(GtkListStore* list_store, gchar* title)
   return widget;
 }
 
-void load_custom_icon(GtkButton* button, gchar** icon_path)
+static void 
+load_custom_icon(GtkButton* button, gchar** icon_path)
 {
   if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button)))
   {
@@ -595,7 +610,8 @@ void load_custom_icon(GtkButton* button, gchar** icon_path)
   }
 }
 
-void icon_selection_dialog(GtkButton* button, editor_data_t* app_data)
+static void 
+icon_selection_dialog(GtkButton* button, editor_data_t* app_data)
 {
   const gchar* icon_name_silent = "statusarea_silent";
   const gchar* icon_name_home = "statusarea_profilesx_home";
@@ -633,6 +649,7 @@ void icon_selection_dialog(GtkButton* button, editor_data_t* app_data)
   gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(icon_button_loud), FALSE);
   gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(icon_button_custom), FALSE);
 
+
   gtk_button_set_image(GTK_BUTTON(icon_button_silent), gtk_image_new_from_icon_name(icon_name_silent, 18));
   gtk_button_set_image(GTK_BUTTON(icon_button_home), gtk_image_new_from_icon_name(icon_name_home, 18));
   gtk_button_set_image(GTK_BUTTON(icon_button_im), gtk_image_new_from_icon_name(icon_name_im, 18));
@@ -696,8 +713,9 @@ void icon_selection_dialog(GtkButton* button, editor_data_t* app_data)
   gtk_widget_destroy(dialog);
 }
 
-
-void init_sound_level_list_store(GtkListStore* list_store)
+static
+void 
+init_sound_level_list_store(GtkListStore* list_store)
 {
   GtkTreeIter iter;
   gtk_list_store_append(list_store, &iter);
@@ -708,7 +726,8 @@ void init_sound_level_list_store(GtkListStore* list_store)
   gtk_list_store_set(list_store, &iter, 0, dgettext("osso-profiles", "profi_va_key_sounds_level2"), 1, 2, -1);
 }
 
-void layout_dialog_widgets(const gchar* profile_name, editor_data_t* data, GtkWidget* dialog)
+static void 
+layout_dialog_widgets(const gchar* profile_name, editor_data_t* data, GtkWidget* dialog)
 {
   GtkWidget* content_area;
   GtkWidget* pannable_area;
@@ -762,7 +781,8 @@ void layout_dialog_widgets(const gchar* profile_name, editor_data_t* data, GtkWi
   }
 }
 
-void init_editor_dialog_widgets(editor_data_t* data)
+static void 
+init_editor_dialog_widgets(editor_data_t* data)
 {
   data->iconButton = hildon_button_new(HILDON_SIZE_FINGER_HEIGHT,
 					   HILDON_BUTTON_ARRANGEMENT_VERTICAL);
@@ -796,14 +816,14 @@ void init_editor_dialog_widgets(editor_data_t* data)
   hildon_check_button_set_active(HILDON_CHECK_BUTTON(data->vibratingCheckbutton), TRUE);
 }
 
-void show_editor_dialog(const gchar* profile_name, GtkWidget* main_dialog, GstElement* sound_player)
+void 
+show_editor_dialog(const gchar* profile_name, GtkWidget* main_dialog, GstElement* sound_player)
 {
   GtkWidget* dialog;
   editor_data_t* data = g_new0(editor_data_t, 1);
   data->profile_data = g_new0(profilesx_profile_data, 1);
   profilesx_load_profile_data(profile_name,
 			      data->profile_data);
-
   dialog = gtk_dialog_new_with_buttons(get_profile_display_name(profile_name),
 				       GTK_WINDOW(main_dialog),
 				       GTK_DIALOG_MODAL,
